@@ -90,7 +90,7 @@ class NaPoleonBinanceFutureBot(object):
     def make_sure_positions_changed(self, positions, sleeping_time = 30):
         position_changed = False
         while not  position_changed:
-            print('updating positions '+positions)
+            print('updating positions '+str(positions))
             position_changed = self.change_position(positions)
             # Prints the current time with a five second difference
             time.sleep(sleeping_time)
