@@ -12,6 +12,7 @@ import json
 # Third party packages
 import pandas as pd
 import pickle
+from datetime import datetime as dt
 # Local packages
 
 __all__ = ['NaPoleonXConnector']
@@ -329,7 +330,8 @@ class NaPoleonXConnector(object):
 
     url_auth = 'https://api.napoleonx.ai/auth-service/oauth/token'
     url = 'https://api.napoleonx.ai/quote-service/v1/eod-quote/filter'
-
+    signal_url = 'https://api.napoleonx.ai/position-service/v1/signal-computation/filter'
+    url_product = 'https://api.napoleonx.ai/product-service/v1/product/'
     data = {
         'grant_type': 'password',
         # 'username': 'arthur',
@@ -382,6 +384,15 @@ class NaPoleonXConnector(object):
         data = json.dumps(kwargs)
         return requests.get(url, data=data, headers=self.headers).json()
 
+    def get_signal_data(self, productCodes, minTs, maxTs, lastOnly):
+        return self._post_request(
+            self.signal_url,
+            productCodes=productCodes,
+            minTs=minTs,
+            maxTs=maxTs,
+            lastOnly=lastOnly
+        )
+
     def get_data(self, productCodes, minDate, maxDate):
         """ Request data.
 
@@ -404,7 +415,14 @@ class NaPoleonXConnector(object):
             self.url,
             productCodes=productCodes,
             minDate=minDate,
-            maxDate=maxDate
+            maxDate=maxDate,
+            lastOnly = True
+        )
+
+    def get_product_data(self, productCodes):
+        return self._post_request(
+            self.url_product,
+            productCodes=productCodes
         )
 
     def _set_dataframe(self, data, assets, keep=['close']):
@@ -447,9 +465,13 @@ class NaPoleonXConnector(object):
                           .rename(columns=columns[asset]))
             asset_col = list(columns[asset].values())
             df.loc[sub_df.index, asset_col] = sub_df.loc[:, asset_col]
-
         return df
 
+    def get_vm_rates_dataframe(self, productCodes, minDate, maxDate):
+        currencies = set([self.get_currency(product_code) for product_code in productCodes])
+        vm_rates_product_codes = [f'VM-EUR-{currency}' for currency in currencies if currency != 'EUR']
+        return self.get_dataframe(vm_rates_product_codes, minDate, maxDate)
+
     def get_dataframe(self, productCodes, minDate, maxDate, keep=['close'],
                       process_na=None):
         """ Request data, clean, sort, and set into pandas dataframe.
@@ -487,3 +509,17 @@ class NaPoleonXConnector(object):
 
         return df
 
+    def get_signal_dataframe(self, productCodes, minDate, maxDate):
+        minTs = dt.strptime(minDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T00:00:00'
+        maxTs = dt.strptime(maxDate, '%Y-%m-%d').strftime('%Y-%m-%d') + 'T23:59:59'
+        signals_df = pd.DataFrame(self.get_signal_data(productCodes,  minTs, maxTs, True))
+        return signals_df
+
+    def get_underlyings(self, productCode):
+        data = self._get_request(self.url_product + productCode)
+        return data['underlyings']
+
+    def get_currency(self, productCode):
+        data = self._get_request(self.url_product + productCode)
+        return data['currency']
+
