@@ -1,4 +1,4 @@
-from napoleontoolbox.forecasting import forecasting_utility
+from napoleontoolbox.mixing import mixing_utility
 
 import lightgbm as lgb
 
